@@ -13,33 +13,38 @@
 #' \donttest{
 #' # Acquire environmental variables
 #' files <- list.files(path = file.path(system.file(package = "dismo"), "ex"),
-#'                     pattern = "grd", full.names = TRUE)
-#' predictors <- raster::stack(files)
+#'                     pattern = "grd",
+#'                     full.names = TRUE)
+#'
+#' predictors <- terra::rast(files)
 #'
 #' # Prepare presence and background locations
 #' p_coords <- virtualSp$presence
 #' bg_coords <- virtualSp$background
 #'
 #' # Create SWD object
-#' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
-#'                    env = predictors, categorical = "biome")
+#' data <- prepareSWD(species = "Virtual species",
+#'                    p = p_coords,
+#'                    a = bg_coords,
+#'                    env = predictors,
+#'                    categorical = "biome")
 #'
 #' # Train a Maxent model
-#' # The next line checks if Maxent is correctly configured but you don't need
-#' # to run it in your script
-#' if (dismo::maxent(silent = TRUE)) {
-#' model <- train(method = "Maxent", data = data, fc = "l")
+#' model <- train(method = "Maxent",
+#'                data = data,
+#'                fc = "l")
 #'
 #' dismo_model <- SDMmodel2MaxEnt(model)
 #' dismo_model
 #' }
-#' }
 #'
 #' @author Sergio Vignali
 SDMmodel2MaxEnt <- function(model) {
 
   if (!inherits(model@model, "Maxent"))
-    stop("'model' must be a SDMmodel object trained using the 'Maxent' method!")
+    cli::cli_abort(c(
+      "!" = "Function available only for {.cls Maxent} models",
+      "x" = "You have supplied a {.cls {class(model@model)}} instead."))
 
   maxent_model <- new("MaxEnt")
   maxent_model@presence <- .get_presence(model@data)
@@ -47,5 +52,5 @@ SDMmodel2MaxEnt <- function(model) {
   maxent_model@lambdas <- model@model@lambdas
   maxent_model@hasabsence <- TRUE
 
-  return(maxent_model)
+  maxent_model
 }
