@@ -5,17 +5,15 @@
 #' @param model \linkS4class{SDMmodel} or \linkS4class{SDMmodelCV} object.
 #' @param var character. Name of the variable to be plotted.
 #' @param type character. The output type used for "Maxent" and "Maxnet"
-#' methods, possible values are "cloglog" and "logistic", default is `NULL`.
-#' @param only_presence logical, if `TRUE` it uses only the presence locations
-#' when applying the function for the marginal response, default is `FALSE`.
-#' @param marginal logical, if `TRUE` it plots the marginal response curve,
-#' default is `FALSE`.
+#' methods, possible values are "cloglog" and "logistic".
+#' @param only_presence logical. If `TRUE` it uses only the presence locations
+#' when applying the function for the marginal response.
+#' @param marginal logical. If `TRUE` it plots the marginal response curve.
 #' @param fun function used to compute the level of the other variables for
-#' marginal curves, default is `mean`.
-#' @param rug logical, if `TRUE` it adds the rug plot for the presence and
-#' absence/background locations, available only for continuous variables,
-#' default is `FALSE`.
-#' @param color The color of the curve, default is "red".
+#' marginal curves.
+#' @param rug logical. If `TRUE` it adds the rug plot for the presence and
+#' absence/background locations, available only for continuous variables.
+#' @param color The colour of the curve, default is "red".
 #'
 #' @details Note that fun is not a character argument, you must use `mean` and
 #' not `"mean"`.
@@ -31,53 +29,87 @@
 #' \donttest{
 #' # Acquire environmental variables
 #' files <- list.files(path = file.path(system.file(package = "dismo"), "ex"),
-#'                     pattern = "grd", full.names = TRUE)
-#' predictors <- raster::stack(files)
+#'                     pattern = "grd",
+#'                     full.names = TRUE)
+#'
+#' predictors <- terra::rast(files)
 #'
 #' # Prepare presence and background locations
 #' p_coords <- virtualSp$presence
 #' bg_coords <- virtualSp$background
 #'
 #' # Create SWD object
-#' data <- prepareSWD(species = "Virtual species", p = p_coords, a = bg_coords,
-#'                    env = predictors, categorical = "biome")
+#' data <- prepareSWD(species = "Virtual species",
+#'                    p = p_coords,
+#'                    a = bg_coords,
+#'                    env = predictors,
+#'                    categorical = "biome")
 #'
 #' # Train a model
-#' model <- train(method = "Maxnet", data = data, fc = "lq")
+#' model <- train(method = "Maxnet",
+#'                data = data,
+#'                fc = "lq")
 #'
 #' # Plot cloglog response curve for a continuous environmental variable (bio1)
-#' plotResponse(model, var = "bio1", type = "cloglog")
+#' plotResponse(model,
+#'              var = "bio1",
+#'              type = "cloglog")
 #'
 #' # Plot marginal cloglog response curve for a continuous environmental
 #' # variable (bio1)
-#' plotResponse(model, var = "bio1", type = "cloglog", marginal = TRUE)
+#' plotResponse(model,
+#'              var = "bio1",
+#'              type = "cloglog",
+#'              marginal = TRUE)
 #'
 #' # Plot logistic response curve for a continuous environmental variable
 #' # (bio12) adding the rugs and giving a custom color
-#' plotResponse(model, var = "bio12", type = "logistic", rug = TRUE,
+#' plotResponse(model,
+#'              var = "bio12",
+#'              type = "logistic",
+#'              rug = TRUE,
 #'              color = "blue")
 #'
 #' # Plot response curve for a categorical environmental variable (biome) giving
 #' # a custom color
-#' plotResponse(model, var = "biome", type = "logistic", color = "green")
+#' plotResponse(model,
+#'              var = "biome",
+#'              type = "logistic",
+#'              color = "green")
 #'
 #' # Train a model with cross validation
-#' folds <- randomFolds(data, k = 4, only_presence = TRUE)
-#' model <- train(method = "Maxnet", data = data, fc = "lq", folds = folds)
+#' folds <- randomFolds(data,
+#'                      k = 4,
+#'                      only_presence = TRUE)
+#'
+#' model <- train(method = "Maxnet",
+#'                data = data,
+#'                fc = "lq",
+#'                folds = folds)
 #'
 #' # Plot cloglog response curve for a continuous environmental variable (bio17)
-#' plotResponse(model, var = "bio1", type = "cloglog")
+#' plotResponse(model,
+#'              var = "bio1",
+#'              type = "cloglog")
 #'
 #' # Plot logistic response curve for a categorical environmental variable
 #' # (biome) giving a custom color
-#' plotResponse(model, var = "biome", type = "logistic", color = "green")
+#' plotResponse(model,
+#'              var = "biome",
+#'              type = "logistic",
+#'              color = "green")
 #' }
-plotResponse <- function(model, var, type = NULL, only_presence = FALSE,
-                         marginal = FALSE, fun = mean, rug = FALSE,
+plotResponse <- function(model,
+                         var,
+                         type = NULL,
+                         only_presence = FALSE,
+                         marginal = FALSE,
+                         fun = mean,
+                         rug = FALSE,
                          color = "red") {
 
   if (!var %in% names(model@data@data))
-    stop(paste(var, "is not used to train the model!"))
+    cli::cli_abort("Variable {.field {var}} is not used to train the model.")
 
   p <- .get_presence(model@data)
   a <- .get_absence(model@data)
@@ -132,7 +164,7 @@ plotResponse <- function(model, var, type = NULL, only_presence = FALSE,
                         aes(x = .data$x, y = .data$y, ymin = .data$y_min,
                             ymax = .data$y_max)) +
         ggplot2::geom_line(colour = color) +
-        ggplot2:: geom_ribbon(fill = color, alpha = 0.2)
+        ggplot2::geom_ribbon(fill = color, alpha = 0.2)
 
     } else {
       my_plot <- ggplot(plot_data, aes(x = .data$x, y = .data$y)) +
@@ -156,12 +188,20 @@ plotResponse <- function(model, var, type = NULL, only_presence = FALSE,
                         sides = "b", color = "#4C4C4C")
   }
 
-  return(my_plot)
+  my_plot
 }
 
 
-.get_plot_data <- function(model, var, df, cont_vars, cat_vars, n_rows, fun,
-                           marginal, type, categ) {
+.get_plot_data <- function(model,
+                           var,
+                           df,
+                           cont_vars,
+                           cat_vars,
+                           n_rows,
+                           fun,
+                           marginal,
+                           type,
+                           categ) {
 
   data <- data.frame(matrix(NA, nrow = 1, ncol = ncol(df)))
   colnames(data) <- colnames(df)
@@ -185,7 +225,7 @@ plotResponse <- function(model, var, type = NULL, only_presence = FALSE,
   }
 
   pred <- predict(model, data, type = type)
-  plot_data <- data.frame(x = data[, var], y = pred)
 
-  return(plot_data)
+  data.frame(x = data[, var],
+             y = pred)
 }
