@@ -1,15 +1,18 @@
 # Get presence locations from an SWD object
 .get_presence <- function(swd) {
-  return(swd@data[swd@pa == 1, , drop = FALSE])
+
+  swd@data[swd@pa == 1, , drop = FALSE]
 }
 
 # Get absence locations from an SWD object
 .get_absence <- function(swd) {
-  return(swd@data[swd@pa == 0, , drop = FALSE])
+
+  swd@data[swd@pa == 0, , drop = FALSE]
 }
 
 # Subset an SWD object using the fold partition
-.subset_swd <- function(swd, fold) {
+.subset_swd <- function(swd,
+                        fold) {
 
   data <- swd@data[fold, , drop = FALSE]
   coords <- swd@coords[fold, , drop = FALSE]
@@ -17,33 +20,41 @@
   rownames(coords) <- NULL
   pa <- swd@pa[fold]
 
-  output <- SWD(species = swd@species, data = data, coords = coords, pa = pa)
-
-  return(output)
+  SWD(species = swd@species,
+      data = data,
+      coords = coords,
+      pa = pa)
 }
 
 .get_model_class <- function(model) {
+
   if (inherits(model, "SDMmodelCV")) {
     model <- model@models[[1]]
   }
-  return(class(model@model))
+
+  class(model@model)
 }
 
 .get_model_reg <- function(model) {
+
   if (inherits(model, "SDMmodelCV")) {
     model <- model@models[[1]]
   }
-  return(model@model@reg)
+
+  model@model@reg
 }
 
 .get_model_fc <- function(model) {
+
   if (inherits(model, "SDMmodelCV")) {
     model <- model@models[[1]]
   }
-  return(model@model@fc)
+
+  model@model@fc
 }
 
 .get_footer <- function(model) {
+
   footer <- c()
   tuned_args <- .get_train_args(model)[getTunableArgs(model)]
 
@@ -51,15 +62,21 @@
     footer <- c(footer, paste0(names(tuned_args)[i], ": ", tuned_args[[i]]))
   }
 
-  return(paste(footer, collapse = "\n"))
+  paste(footer, collapse = "\n")
 }
 
-.get_total_models <- function(pop, gen, remaining) {
-  tot <- pop + (gen * remaining)
-  return(tot)
+.get_total_models <- function(pop,
+                              gen,
+                              remaining) {
+
+  pop + (gen * remaining)
 }
 
-.get_metric <- function(metric, model, test = NULL, env = NULL) {
+.get_metric <- function(metric,
+                        model,
+                        test = NULL,
+                        env = NULL) {
+
   if (metric == "auc") {
     return(auc(model, test))
   } else if (metric == "tss") {
@@ -70,6 +87,7 @@
 }
 
 .get_metric_label <- function(metric) {
+
   if (metric == "auc") {
     return("AUC")
   } else if (metric == "tss") {
@@ -80,6 +98,7 @@
 }
 
 .get_sdmtune_colnames <- function(metric) {
+
   if (metric == "auc") {
     return(c("train_AUC", "test_AUC", "diff_AUC"))
   } else if (metric == "tss") {
@@ -89,7 +108,10 @@
   }
 }
 
-.create_sdmtune_result <- function(model, metric, train_metric, val_metric) {
+.create_sdmtune_result <- function(model,
+                                   metric,
+                                   train_metric,
+                                   val_metric) {
 
   tunable_hypers <- getTunableArgs(model)
   l <- length(tunable_hypers)
@@ -116,10 +138,13 @@
 
   names(res) <- labels
 
-  return(res)
+  res
 }
 
-.create_sdmtune_output <- function(models, metric, train_metric, val_metric) {
+.create_sdmtune_output <- function(models,
+                                   metric,
+                                   train_metric,
+                                   val_metric) {
 
   tunable_hypers <- getTunableArgs(models[[1]])
   l <- length(tunable_hypers)
@@ -131,11 +156,13 @@
   distrs <- vector("character", length = length(models))
 
   for (i in seq_along(models)) {
+
     if (inherits(models[[i]], "SDMmodel")) {
       m <- models[[i]]
     } else {
       m <- models[[i]]@models[[1]]
     }
+
     for (j in 1:l) {
       if (tunable_hypers[j] == "distribution") {
         distrs[i] <- slot(m@model, tunable_hypers[j])
@@ -145,7 +172,9 @@
         res[i, tunable_hypers[j]] <- slot(m@model, tunable_hypers[j])
       }
     }
+
     res[i, l + 1] <- train_metric[i, 2]
+
     if (metric != "aicc")
       res[i, l + 2] <- val_metric[i, 2]
   }
@@ -161,13 +190,13 @@
   if ("distribution" %in% tunable_hypers) {
     res$distribution <- distrs
   }
+
   if ("fc" %in% tunable_hypers) {
     res$fc <- fcs
   }
 
-  output <- SDMtune(results = res, models = models)
-
-  return(output)
+  SDMtune(results = res,
+          models = models)
 }
 
 .get_train_args <- function(model) {
@@ -176,6 +205,7 @@
 
   if (inherits(model, "SDMmodelCV")) {
     args$folds <- model@folds
+    args$progress <- FALSE
     model <- model@models[[1]]@model
   } else {
     args$folds <- NULL
@@ -207,52 +237,72 @@
     args$shrinkage <- model@shrinkage
     args$bag.fraction <- model@bag.fraction
   }
-  return(args)
+
+  args
 }
 
-.create_model_from_settings <- function(model, settings, verbose = FALSE) {
+.create_model_from_settings <- function(model,
+                                        settings) {
 
   args <- .get_train_args(model)
   args[names(settings)] <- settings
-  args$verbose <- verbose
-  output <- suppressMessages(do.call("train", args))
 
-  return(output)
+  do.call("train", args)
 }
 
-.check_args <- function(model, metric, test = NULL, env = NULL, hypers = NULL) {
+.check_args <- function(model,
+                        metric,
+                        test = NULL,
+                        env = NULL,
+                        hypers = NULL,
+                        is_do_jk = FALSE) {
+
   # Throws exception if metric is aicc and env is not provided
   if (metric == "aicc" & is.null(env) & inherits(model, "SDMmodel"))
-    stop("You must provide the 'env' argument if you want to use the AICc ",
-         "metric!")
+    cli::cli_abort(
+      "You must provide the {.var env} argument if you want to use the AICc"
+      )
+
   # Throws exception if model is SDMmodel, metric is not aicc and
   # test is not provided
   if (inherits(model, "SDMmodel") & is.null(test) & metric != "aicc") {
-    stop("You need to provide a test dataset!")
+
+    # Only if the call is not from doJk()
+    if (!is_do_jk)
+      cli::cli_abort("You need to provide a test dataset")
   }
+
   # Throws exception if metric is aicc and model is SDMmodelCV
   if (inherits(model, "SDMmodelCV") & metric == "aicc")
-    stop("Metric 'aicc' not allowed with SDMmodelCV objects!")
+    cli::cli_abort("{.strong AICc} not allowed with {.cls SDMmodelCV} objects")
+
   # Check hypers
   if (!is.null(hypers)) {
     # Throws exception if provided hypers are not tunable
+
     diff <- setdiff(names(hypers), getTunableArgs(model))
+
     if (length(diff) > 0)
-      stop(paste(diff, "non included in tunable hyperparameters",
-                 collapse = ", "))
+      cli::cli_abort(
+        ("Argumnt{?s} {diff} non included in tunable hyperparameters")
+      )
   }
 }
 
-.get_hypers_grid <- function(model, hypers) {
+.get_hypers_grid <- function(model,
+                             hypers) {
+
   # Create data frame with all possible combinations of hyperparameters
   tunable_args <- .get_train_args(model)[getTunableArgs(model)]
   tunable_args[names(hypers)] <- hypers
-  grid <- expand.grid(tunable_args, stringsAsFactors = FALSE)
-  return(grid)
+
+  expand.grid(tunable_args,
+              stringsAsFactors = FALSE)
 }
 
 .args_name <- function(x) {
-  output <- switch(x,
+
+  switch(x,
     "trainANN" = c("data", "size", "decay", "rang", "maxit"),
     "trainBRT" = c("data", "distribution", "n.trees", "interaction.depth",
                    "shrinkage", "bag.fraction"),
@@ -260,5 +310,13 @@
     "trainMaxnet" = c("data", "reg", "fc"),
     "trainRF" = c("data", "mtry", "ntree", "nodesize")
   )
-  return(output)
+}
+
+# TODO: Remove with version 2.0.0
+.warn_raster <- function(x, y) {
+  cli::cli_warn(
+    c("!" = "{.cls {x}} objects will not be accepted in future releases",
+      "i" = paste("{.pkg SDMtune} now uses {.pkg terra} to handle spatial",
+                  "data. See function {.fun terra::{y}} to migrate."))
+  )
 }
