@@ -1,10 +1,12 @@
 skip_on_cran()
-skip_on_appveyor()
 
 test_that("The function trainBRT produces the correct ouput", {
   data <- SDMtune:::t
   data@data <- data@data[, 1:4]
-  m <- trainBRT(data = data, n.trees = 200, shrinkage = 0.2)
+  m <- trainBRT(data = data,
+                n.trees = 200,
+                shrinkage = 0.2)
+
   expect_s4_class(m, "SDMmodel")
   expect_s4_class(m@model, "BRT")
   expect_s4_class(m@data, "SWD")
